@@ -8,15 +8,15 @@ This module contains the following classes:
 '''
 
 from dataclasses import dataclass, field
-from order import Order
 from tda.orders import equities
 from tda import auth, client
 from typing import Iterable
-from pathlib import Path
 
+
+import json
+import os
 import pandas as pd
-import dotenv
-import os, json
+import selenium
 
 
 @dataclass
@@ -74,12 +74,12 @@ class AccountClient:
     @property
     def balance(self):
         response = self.client.get_account(self.ACC_ID).json()
-        return response['securitiesAccount']['initialBalances']['liquidationValue']
+        return response['securitiesAccount']['currentBalances']['liquidationValue']
 
     @property
     def cash(self):
         response = self.client.get_account(self.ACC_ID).json()
-        return response['securitiesAccount']['initialBalances']['cashAvailableForTrading']
+        return response['securitiesAccount']['currentBalances']['cashAvailableForTrading']
 
     @property
     def order(self):
@@ -115,15 +115,19 @@ class AccountClient:
 
         return position_df    
 
-    def get_price(self, symbol: list):
+    def get_price(self, symbol):
         response = self.client.get_quotes(symbol).json()
         entries = dict()
+
+        if type(symbol) is str:
+            return {symbol:response[symbol]['lastPrice']}
+        
         for sym in symbol:
             entries[sym] = response[sym]['lastPrice']
             
         return entries
 
-    def place_order_TDAmeritrade(self, book: Iterable[Order]):
+    def place_order_TDAmeritrade(self, book):
         order_queue = list()
 
         for order in book:
@@ -133,4 +137,14 @@ class AccountClient:
                 order_queue.append(order)
 
         for order in order_queue:
-            self.__submitBuy(order)
\ No newline at end of file
+            self.__submitBuy(order)
+
+def refresh_token(webdriver_func, api_key, redirect_uri, token_path=None):
+    auth.client_from_login_flow(
+        webdriver=webdriver_func,
+        api_key=api_key,
+        redirect_url=redirect_uri,
+        token_path=token_path,
+    )
+
+    return
\ No newline at end of file
